@@ -1,6 +1,7 @@
 import re
 
 from django.core.exceptions import ValidationError
+from django.utils.safestring import mark_safe
 from wagtail.core.blocks import RichTextBlock
 
 FIND_FOOTNOTE_TAG = re.compile(r'<footnote id="(.*?)">.*?</footnote>')
@@ -20,17 +21,16 @@ class RichTextBlockWithFootnotes(RichTextBlock):
 
         def replace_tag(match):
             try:
-                index = self.process_footnote(match.group(1), context)
+                index = self.process_footnote(match.group(1), context["page"])
             except (KeyError, ValidationError):
                 return ""
             else:
                 return f'<a href="#footnote-{index}" id="footnote-source-{index}"><sup>[{index}]</sup></a>'
+        return mark_safe(FIND_FOOTNOTE_TAG.sub(replace_tag, html))
 
-        return FIND_FOOTNOTE_TAG.sub(replace_tag, html)
-
-    def process_footnote(self, footnote_id, context):
-        footnotes = self.get_footnotes(context["page"])
-        footnote = context["page"].footnotes.get(uuid=footnote_id)
+    def process_footnote(self, footnote_id, page):
+        footnotes = self.get_footnotes(page)
+        footnote = page.footnotes.get(uuid=footnote_id)
         if footnote not in footnotes:
             footnotes.append(footnote)
         return footnotes.index(footnote) + 1
